/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <system_info.h>
#include "$(appName).h"
#include "data.h"

/**
 * @brief Function obtains the boolean value associated with the feature.
 * @param[in] feature The feature name.
 * @return This function returns the boolean value associated with the provided feature.
 */
bool data_get_feature_state(const char *feature)
{
	bool value = false;
	int ret = system_info_get_platform_bool(feature, &value);
	if (ret != SYSTEM_INFO_ERROR_NONE) {
		dlog_print(DLOG_ERROR, LOG_TAG, "system_info_get_platform_bool() failed (%d): %s", ret, get_error_message(ret));
		return false;
	}

	return value;
}

/**
 * @brief Function obtains the string value associated with the feature.
 * @param[in] feature The feature name.
 * @return This function returns the string value associated with the provided feature.
 */
char *data_get_feature_description(const char *feature)
{
	char *value = NULL;
	int ret = system_info_get_platform_string(feature, &value);
	if (ret != SYSTEM_INFO_ERROR_NONE) {
		dlog_print(DLOG_ERROR, LOG_TAG, "system_info_get_platform_string() failed (%d): %s", ret, get_error_message(ret));
		return false;
	}

	return value;
}

/**
 * @brief Function obtains the integer value associated with the feature.
 * @param[in] feature The feature name.
 * @return This function returns the integer value associated with the provided feature.
 */
int data_get_feature_value(const char *feature)
{
	int value;
	int ret = system_info_get_platform_int(feature, &value);
	if (ret != SYSTEM_INFO_ERROR_NONE) {
		dlog_print(DLOG_ERROR, LOG_TAG, "system_info_get_platform_int() failed (%d): %s", ret, get_error_message(ret));
		return false;
	}

	return value;
}
